@@ -17,13 +17,12 @@
 #  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #  =============================================================================
 
-from .structs.trade_api_struct import *
-from .structs.trade_spi_struct import *
+from .structs import *
 
 from .src import AztTradeApi, AztTradeSpi
 from .src import AztQuoteApi, AztQuoteSpi
 
-from .protobufs.EnumType_pb2 import *
+from .protos.EnumType_pb2 import *
 from AztVe.common.azt_errors import *
 
 from .common.azt_logger import debug, log, warning, error, init_azt_log
