@@ -18,9 +18,9 @@
 #  =============================================================================
 
 from . import azt_logger as logger
-from . import azt_dataclass as datacls
-
-from .azt_socket_zmq import Socket as ZmqSocketCls
+from .qujam_struct_for_azt import AztStructs
 from .qujam_socket import QujamSocket, HeaderRecvPolicy, HeaderSendPolicy
+from .qujam_socket_zmq import QujamSocketZmq
+from .qujam_func_switch import QujamFuncSwitch
 from .azt_errors import *
 from .utils import *
