@@ -82,3 +82,11 @@ class SubscribeError(AztException):
 # 退订失败
 class UnsubscribeError(AztException):
     _msg = "取消订阅失败"
+
+
+class CloseSocketZmq(AztException):
+    _msg = "主动断开与zmq服务端的连接"
+
+
+class CloseSocket(AztException):
+    _msg = "主动断开与服务端的连接"
