@@ -16,5 +16,5 @@
 #  You should have received a copy of the GNU Lesser General Public License
 #  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #  =============================================================================
-from .quote_api import QuoteApi
-from .quote_spi import QuoteSpi
+from .quote_api import AztQuoteApi
+from .quote_spi import AztQuoteSpi
