@@ -33,11 +33,6 @@ class QuoteApiBase(common.AztApiObject):
         self.spi = AztQuoteSpi()
         self.__req_queue_manage = dict()
 
-        # self._heart_beat_times = 3  # 心跳次数
-        # self._heart_beat_count = self._heart_beat_times  # 心跳倒数
-        # self._heart_beat_interval = 5  # 心跳间隔时间，5秒
-        # self._heart_beat_req = self.__init_heart_beat_req()  # 心跳请求
-
     # queue manage -----------------------------------------------------------------------------------------------------
     def __queue_subscribe(self, msg_id):
         if msg_id not in self.__req_queue_manage:
@@ -64,26 +59,6 @@ class QuoteApiBase(common.AztApiObject):
                 self.__queue_unsubscribe(msg_id)
         return None
 
-    # def __heart_beat(self):
-    #     while self._heart_beat_count > 0 and not self.__tcp_socket.is_closed():
-    #         self._heart_beat_count -= 1
-    #         self.__send_heart_beat()
-    #         time.sleep(self._heart_beat_interval)
-    #     if not self.__tcp_socket.is_closed():
-    #         logger.error("与服务器连接已中断！")
-    #         err = self._stop()
-    #         if err:
-    #             raise err
-    #         self.spi.quoteConnectionBroken()
-    #
-    # @staticmethod
-    # def __init_heart_beat_req():
-    #     unitedmsg = UnitMsgProto.UnitedMessage(msg_type=MsgProto.KQuoteMsgType_HeartBeat)
-    #     return unitedmsg.SerializeToString()
-    #
-    # def __send_heart_beat(self):
-    #     self.__tcp_socket.send(self._heart_beat_req)
-
     @staticmethod
     def __gen_unit_msg(msg, msg_id, msg_type=MsgProto.KQuoteMsgType_Unknown):
         unit_msg = UnitMsgProto.UnitedMessage(msg_type=msg_type, msg_id=msg_id)
@@ -91,7 +66,6 @@ class QuoteApiBase(common.AztApiObject):
         return unit_msg.SerializeToString()
 
     def __tcp_recv_handle(self, msg):
-        logger.debug("收到tcp消息,长度:", len(msg))
         # 解析msg
         unitedmsg = UnitMsgProto.UnitedMessage()
         try:
@@ -102,15 +76,21 @@ class QuoteApiBase(common.AztApiObject):
 
         msg_type = unitedmsg.msg_type
         if msg_type == MsgProto.KQuoteMsgType_HeartBeat:
-            self._heart_beat_count = self._heart_beat_times
-            self.__queue_put(MsgProto.KQuoteMsgType_HeartBeat, True)
+            self.__socket.keep_heart_beat()
+
         elif msg_type == MsgProto.KQuoteMsgType_TcpConnConfirm:
             tcp_cc = MsgProto.TcpConnectionConfirm()
             unitedmsg.msg_body.Unpack(tcp_cc)
             self.__queue_put(MsgProto.KQuoteMsgType_TcpConnConfirm, tcp_cc)
         elif msg_type == MsgProto.KQuoteMsgType_RealTime:
             msg_id = unitedmsg.msg_id
-            if msg_id == MsgProto.KQuoteMsgID_QuoteRegister:  # 订阅回复
+            if msg_id == MsgProto.KQuoteMsgID_QuoteSnapshot:
+                data = MsgProto.QuoteData()
+                unitedmsg.msg_body.Unpack(data)
+                if data.data_type == MsgProto.KMarketDataType_V2_Actual:  # 股票数据
+                    ret = quote_spi_struct.StockQuoteData.__proto2py__(data, 2)
+                    self.spi.onDepthMarketData(ret)
+            elif msg_id == MsgProto.KQuoteMsgID_QuoteRegister:  # 订阅回复
                 register_rsp = MsgProto.QuoteRegisterRsp()
                 unitedmsg.msg_body.Unpack(register_rsp)
                 ret = quote_spi_struct.QuoteRegisterRsp.__proto2py__(register_rsp)
@@ -120,19 +100,12 @@ class QuoteApiBase(common.AztApiObject):
                 unitedmsg.msg_body.Unpack(unregister)
                 ret = quote_spi_struct.QuoteRegisterRsp.__proto2py__(unregister)
                 self.spi.onUnSubscribe(ret)
-            elif msg_id == MsgProto.KQuoteMsgID_QuoteSnapshot:
-                data = MsgProto.QuoteData()
-                unitedmsg.msg_body.Unpack(data)
-                if data.data_type == MsgProto.KMarketDataType_V2_Actual:  # 股票数据
-                    ret = quote_spi_struct.StockQuoteData.__proto2py__(data, 2)
-                    self.spi.onDepthMarketData(ret)
 
     def __udp_recv_handle(self, msg):
-        logger.debug("收到udp消息长度:", len(msg))
         unitedmsg = UnitMsgProto.UnitedMessage()
         try:
             unitedmsg.ParseFromString(msg)
-        except:
+        except MsgProto._message.DecodeError:
             logger.debug("反序列化失败,发生数据丢包")
             return
         if unitedmsg.msg_type != MsgProto.KQuoteMsgType_RealTime or \
@@ -149,7 +122,7 @@ class QuoteApiBase(common.AztApiObject):
         self.spi.quoteConnectionBroken(err)
         pass
 
-    def _start(self, ip, port, spi=None, timeout=None, set_heart_beat=False):
+    def _start(self, ip, port, spi=None, timeout=None):
         # self.__tcp_socket = TcpSocketCls()
         self.__socket = QujamSocket()
 
@@ -162,46 +135,43 @@ class QuoteApiBase(common.AztApiObject):
         self.__socket.set_tcp_send_policy(HeaderSendPolicy)
 
         error = self.__socket.connect_tcp(ip, port, timeout)
+        if error:
+            return error
 
-        if not error:
-            setattr(self, "is_closed", self._is_closed)
-            if spi:
-                self.spi = common.DefaultSpi(spi)
-            # 发送tcp连接确认请求
-            tcp_cc = UnitMsgProto.UnitedMessage(msg_type=MsgProto.KQuoteMsgType_TcpConnConfirm)
-            tcp_cc_rep = self._get_result(MsgProto.KQuoteMsgType_TcpConnConfirm, 3, True,
-                                          self.__socket.send_tcp, tcp_cc.SerializeToString())
-            if tcp_cc_rep is None:
-                self._stop()
-                return common.ConnectedFailed(f"服务器 - {ip}:{port} - 连接失败！")
+        setattr(self, "is_closed", self._is_closed)
+        if spi:
+            self.spi = common.DefaultSpi(spi)
+        # 发送tcp连接确认请求
+        tcp_cc = UnitMsgProto.UnitedMessage(msg_type=MsgProto.KQuoteMsgType_TcpConnConfirm)
+        tcp_cc_rep = self._get_result(MsgProto.KQuoteMsgType_TcpConnConfirm, 3, True,
+                                      self.__socket.send_tcp, tcp_cc.SerializeToString())
+        if tcp_cc_rep is None:
+            self._stop()
+            return common.ConnectedFailed(f"服务器 - {ip}:{port} - 连接失败！")
 
-            if tcp_cc_rep.use_udp:
-                self.__socket.set_udp_recv_cb(self.__udp_recv_handle)
-                self.__socket.set_udp_recv_err(self.__socket_err_handle)
+        if tcp_cc_rep.use_udp:
+            self.__socket.set_udp_recv_cb(self.__udp_recv_handle)
+            self.__socket.set_udp_recv_err(self.__socket_err_handle)
 
-                self.__socket.connect_udp(ip, tcp_cc_rep.udp_port)
+            self.__socket.connect_udp(ip, tcp_cc_rep.udp_port)
 
-                united_msg = UnitMsgProto.UnitedMessage(msg_type=MsgProto.KQuoteMsgType_UdpConnConfirm)
-                udp_cc = MsgProto.UdpConnectionConfirm(tcp_owner=tcp_cc_rep.tcp_owner)
-                united_msg.msg_body.Pack(udp_cc)
-                self.__socket.send_udp(united_msg.SerializeToString())
+            united_msg = UnitMsgProto.UnitedMessage(msg_type=MsgProto.KQuoteMsgType_UdpConnConfirm)
+            udp_cc = MsgProto.UdpConnectionConfirm(tcp_owner=tcp_cc_rep.tcp_owner)
+            united_msg.msg_body.Pack(udp_cc)
+            self.__socket.send_udp(united_msg.SerializeToString())
 
-                self.__socket.make_loop_thread(self.__socket.send_udp, fargs=(b"1",), btime=10)
+            self.__socket.make_loop_thread(self.__socket.send_udp, fargs=(b"1",), btime=10)
 
-            logger.debug(f"已连接行情服务 - {ip}:{port}")
-
-            # if set_heart_beat:
-            #     self.__thread_heart_beat = threading.Thread(target=self.__heart_beat)
-            #     self.__thread_heart_beat.setDaemon(True)
-            #     self.__thread_heart_beat.start()
-
-        return error
+        logger.debug(f"已连接行情服务 - {ip}:{port}")
 
     def _is_closed(self):
-        return self.__socket.is_closed()
+        if self.__socket:
+            return self.__socket.is_closed()
+        return True
 
     def _stop(self):
-        return self.__socket.close()
+        if self.__socket:
+            return self.__socket.close()
 
     def _join(self, timeout=None):
         self.__socket.join(timeout)
@@ -225,7 +195,6 @@ class QuoteApiBase(common.AztApiObject):
         unitedmsg = self.__gen_unit_msg(req, MsgProto.KQuoteMsgID_UnRegister, MsgProto.KQuoteMsgType_RealTime)
         return self.__socket.send_tcp(unitedmsg)
 
-    # def __sync_mode_wrapper(self, req, sync=False, timeout=None, rid=None, once=False):
-    #     if sync:
-    #         return self._get_result(rid, timeout, once, self.__socket.send_tcp, req)
-    #     self.__socket.send_tcp(req)
+    def _set_heart_beat(self, hb_times: int = 3, hb_tv: int = 5):
+        unitedmsg = UnitMsgProto.UnitedMessage(msg_type=MsgProto.KQuoteMsgType_HeartBeat)
+        self.__socket.set_heart_beat(unitedmsg.SerializeToString(), hb_times, hb_tv)
