@@ -21,11 +21,7 @@ class AztTradeSpi:
     api = None  # AztTradeApi实例引用
 
     # 连接中断回报，一旦被调用，则说明客户端与服务端的连接中断了
-    def connectionBroken(self):
-        pass
-
-    # 注册模拟柜台账户回报，msg为RegisterAck实例
-    def onRegisterAccount(self, msg):
+    def tradeConnectionBroken(self, err):
         pass
 
     # 登录回报，msg为LoginAck实例
