@@ -18,26 +18,26 @@
 #  =============================================================================
 
 import datetime
-from AztVe.common.azt_dataclass import aztdataclass
+from AztVe.common.qujam_struct_for_azt import AztStructs
 from ..protos import Trade_Message_pb2 as proto
 
 
 # ve账户注册请求
-@aztdataclass(proto.RegisterReq)
+@AztStructs(proto.RegisterReq)
 class RegisterReq:
     strategy_id: str = None
     strategy_check_code: str = None
 
 
 # ve账户登录请求
-@aztdataclass(proto.LoginReq)
+@AztStructs(proto.LoginReq)
 class LoginReq:
     account: str = None
     passwd: str = None
 
 
 # ve账户登出请求
-@aztdataclass(proto.LogoutReq)
+@AztStructs(proto.LogoutReq)
 class LogoutReq:
     account: str = None
 
@@ -46,7 +46,7 @@ class LogoutReq:
 # account and passwd | strategy and check_code
 # 若查询条件是 strategy_id + check_code，则返回 所有；
 # 若查询条件是 account + passwd; 则只返回 account 和 acc_satus
-@aztdataclass(proto.UserInfoQryReq)
+@AztStructs(proto.UserInfoQryReq)
 class UserInfoQryReq:
     account: str = None
     passwd: str = None
@@ -55,7 +55,7 @@ class UserInfoQryReq:
 
 
 # 账户入金请求
-@aztdataclass(proto.AccDepositReq, amount_dec="amount_decimal_place", adj_amount=["amount"],
+@AztStructs(proto.AccDepositReq, amount_dec="amount_decimal_place", adj_amount=["amount"],
               adj_time=dict(sending_time="%Y%m%d-%H:%M:%S.%f"))
 class AccDepositReq:
     sender_user: str = None
@@ -66,7 +66,7 @@ class AccDepositReq:
 
 
 # 账户资金信息查询请求
-@aztdataclass(proto.TradingAccQryReq)
+@AztStructs(proto.TradingAccQryReq)
 class TradingAccQryReq:
     account: str = None
 
@@ -75,7 +75,7 @@ class TradingAccQryReq:
 # 除account外，皆可为空；
 # client_ref 与 order_id 只填写一个即可, 则不填写market和code
 # 查询未结委托，只填写 account 与 unfinished=true
-@aztdataclass(proto.QueryOrdersReq)
+@AztStructs(proto.QueryOrdersReq)
 class QueryOrdersReq:
     account: str = None  # 必填
     market: str = None  # 选填
@@ -88,7 +88,7 @@ class QueryOrdersReq:
 # 查询交易信息请求
 # 除account外，皆可为空
 # trade_id 或 account market code order_id 填写，则无效（不用填写）
-@aztdataclass(proto.QueryTradesReq)
+@AztStructs(proto.QueryTradesReq)
 class QueryTradesReq:
     account: str = None
     market: str = None
@@ -99,7 +99,7 @@ class QueryTradesReq:
 
 # 查询持仓请求
 # 除account外，皆可为空
-@aztdataclass(proto.QueryPositionsReq)
+@AztStructs(proto.QueryPositionsReq)
 class QueryPositionsReq:
     account: str = None
     market: str = None
@@ -108,7 +108,7 @@ class QueryPositionsReq:
 
 # 查询历史订单记录请求
 # market code 可空
-@aztdataclass(proto.QueryHistoryOrdersReq,
+@AztStructs(proto.QueryHistoryOrdersReq,
               adj_time=dict(start_time="%Y%m%d-%H:%M:%S.%f", end_time="%Y%m%d-%H:%M:%S.%f"))
 class QueryHistoryOrdersReq:
     account: str = None
@@ -120,7 +120,7 @@ class QueryHistoryOrdersReq:
 
 # 查询历史交易记录请求
 # market code 可空
-@aztdataclass(proto.QueryHistoryTradesReq,
+@AztStructs(proto.QueryHistoryTradesReq,
               adj_time=dict(start_time="%Y%m%d-%H:%M:%S.%f", end_time="%Y%m%d-%H:%M:%S.%f"))
 class QueryHistoryTradesReq:
     account: str = None
@@ -130,20 +130,20 @@ class QueryHistoryTradesReq:
     end_time: datetime.datetime = None
 
 
-@aztdataclass(proto.QryHisAccReq, adj_time=dict(settlement_date="%Y%m%d-%H:%M:%S.%f"))
+@AztStructs(proto.QryHisAccReq, adj_time=dict(settlement_date="%Y%m%d-%H:%M:%S.%f"))
 class QryHisAccReq:
     account: str = None
     settlement_date: datetime.datetime = None
 
 
-@aztdataclass(proto.QryHisDepositReq, adj_time=dict(settlement_date="%Y%m%d-%H:%M:%S.%f"))
+@AztStructs(proto.QryHisDepositReq, adj_time=dict(settlement_date="%Y%m%d-%H:%M:%S.%f"))
 class QryHisDepositReq:
     account: str = None
     settlement_date: datetime.datetime = None
 
 
 # 委托订单请求
-@aztdataclass(proto.PlaceOrder, price_dec="price_decimal_place", adj_price=["order_price", "discretion_price"],
+@AztStructs(proto.PlaceOrder, price_dec="price_decimal_place", adj_price=["order_price", "discretion_price"],
               adj_time=dict(send_time=["%Y%m%d-%H:%M:%S.%f", "%Y%m%d-%H:%M:%S"]))
 class PlaceOrder:
     client_ref: str = None
@@ -163,7 +163,7 @@ class PlaceOrder:
 
 
 # 撤单请求
-@aztdataclass(proto.CancelOrder, adj_time=dict(send_time="%Y%m%d-%H:%M:%S.%f"))
+@AztStructs(proto.CancelOrder, adj_time=dict(send_time="%Y%m%d-%H:%M:%S.%f"))
 class CancelOrder:
     client_ref: str = None
     sender_user: str = None
